qcacld-3.0: Replace typedef tCsrRoamInfo

The Linux Coding Style enumerates a few special cases where typedefs
are useful, but stresses "NEVER EVER use a typedef unless you can
clearly match one of those rules." The tCsrRoamInfo typedef does not
meet any of those criteria, and the underlying struct is already being
used in some places, so replace all remaining tCsrRoamInfo references
with a reference to the underlying struct.

Change-Id: I1da4b04ec92e176fe28b33d30ec7823828c35c8d
CRs-Fixed: 2140349
diff --git a/core/hdd/inc/wlan_hdd_assoc.h b/core/hdd/inc/wlan_hdd_assoc.h
index 299c7c1..8a31c9c 100644
--- a/core/hdd/inc/wlan_hdd_assoc.h
+++ b/core/hdd/inc/wlan_hdd_assoc.h
@@ -249,7 +249,8 @@
  *
  * Return: QDF_STATUS enumeration
  */
-QDF_STATUS hdd_sme_roam_callback(void *pContext, tCsrRoamInfo *roam_info,
+QDF_STATUS hdd_sme_roam_callback(void *pContext,
+				 struct csr_roam_info *roam_info,
 				 uint32_t roamId,
 				 eRoamCmdStatus roamStatus,
 				 eCsrRoamResult roamResult);
@@ -328,9 +329,9 @@
 				 enum ol_txrx_peer_state sta_state,
 				 bool roam_synch_in_progress);
 #ifdef WLAN_FEATURE_ROAM_OFFLOAD
-bool hdd_is_roam_sync_in_progress(tCsrRoamInfo *roaminfo);
+bool hdd_is_roam_sync_in_progress(struct csr_roam_info *roaminfo);
 #else
-static inline bool hdd_is_roam_sync_in_progress(tCsrRoamInfo *roaminfo)
+static inline bool hdd_is_roam_sync_in_progress(struct csr_roam_info *roaminfo)
 {
 	return false;
 }
@@ -364,14 +365,14 @@
  * Return: None
  */
 void hdd_save_gtk_params(struct hdd_adapter *adapter,
-			 tCsrRoamInfo *csr_roam_info, bool is_reassoc);
+			 struct csr_roam_info *csr_roam_info, bool is_reassoc);
 #else
 static inline void hdd_wma_send_fastreassoc_cmd(struct hdd_adapter *adapter,
 		const tSirMacAddr bssid, int channel)
 {
 }
 static inline void hdd_save_gtk_params(struct hdd_adapter *adapter,
-				       tCsrRoamInfo *csr_roam_info,
+				       struct csr_roam_info *csr_roam_info,
 				       bool is_reassoc)
 {
 }
diff --git a/core/hdd/inc/wlan_hdd_main.h b/core/hdd/inc/wlan_hdd_main.h
index a7a9ae4..b9ced9e 100644
--- a/core/hdd/inc/wlan_hdd_main.h
+++ b/core/hdd/inc/wlan_hdd_main.h
@@ -2436,7 +2436,7 @@
 	const u8 *ssid, size_t ssid_len);
 
 void hdd_connect_result(struct net_device *dev, const u8 *bssid,
-			tCsrRoamInfo *roam_info, const u8 *req_ie,
+			struct csr_roam_info *roam_info, const u8 *req_ie,
 			size_t req_ie_len, const u8 *resp_ie,
 			size_t resp_ie_len, u16 status, gfp_t gfp,
 			bool connect_timeout,
@@ -2763,12 +2763,13 @@
  *
  * Return: None
  */
-void hdd_update_hlp_info(struct net_device *dev, tCsrRoamInfo *roam_info);
+void hdd_update_hlp_info(struct net_device *dev,
+			 struct csr_roam_info *roam_info);
 #else
 static inline void hdd_clear_fils_connection_info(struct hdd_adapter *adapter)
 { }
 static inline void hdd_update_hlp_info(struct net_device *dev,
-				       tCsrRoamInfo *roam_info)
+				       struct csr_roam_info *roam_info)
 {}
 #endif
 
diff --git a/core/hdd/inc/wlan_hdd_wmm.h b/core/hdd/inc/wlan_hdd_wmm.h
index 67362e5..d8d1034 100644
--- a/core/hdd/inc/wlan_hdd_wmm.h
+++ b/core/hdd/inc/wlan_hdd_wmm.h
@@ -317,7 +317,8 @@
  * Return: QDF_STATUS enumeration
  */
 QDF_STATUS hdd_wmm_assoc(struct hdd_adapter *adapter,
-			 tCsrRoamInfo *roam_info, eCsrRoamBssType eBssType);
+			 struct csr_roam_info *roam_info,
+			 eCsrRoamBssType eBssType);
 
 /**
  * hdd_wmm_connect() - Function which will handle the housekeeping
@@ -330,7 +331,8 @@
  * Return: QDF_STATUS enumeration
  */
 QDF_STATUS hdd_wmm_connect(struct hdd_adapter *adapter,
-			   tCsrRoamInfo *roam_info, eCsrRoamBssType eBssType);
+			   struct csr_roam_info *roam_info,
+			   eCsrRoamBssType eBssType);
 
 /**
  * hdd_wmm_get_uapsd_mask() - Function which will calculate the
diff --git a/core/hdd/src/wlan_hdd_assoc.c b/core/hdd/src/wlan_hdd_assoc.c
index 505bb39..3c3ab8f 100644
--- a/core/hdd/src/wlan_hdd_assoc.c
+++ b/core/hdd/src/wlan_hdd_assoc.c
@@ -354,7 +354,7 @@
  * Return: None
  */
 static void hdd_copy_ht_caps(struct hdd_station_ctx *hdd_sta_ctx,
-				     tCsrRoamInfo *roam_info)
+				     struct csr_roam_info *roam_info)
 {
 	tDot11fIEHTCaps *roam_ht_cap = &roam_info->ht_caps;
 	struct ieee80211_ht_cap *hdd_ht_cap = &hdd_sta_ctx->conn_info.ht_caps;
@@ -548,7 +548,7 @@
  * Return: None
  */
 static void hdd_copy_vht_caps(struct hdd_station_ctx *hdd_sta_ctx,
-				     tCsrRoamInfo *roam_info)
+				     struct csr_roam_info *roam_info)
 {
 	tDot11fIEVHTCaps *roam_vht_cap = &roam_info->vht_caps;
 	struct ieee80211_vht_cap *hdd_vht_cap =
@@ -663,7 +663,7 @@
  * Return: None
  */
 static void hdd_copy_ht_operation(struct hdd_station_ctx *hdd_sta_ctx,
-					    tCsrRoamInfo *roam_info)
+					    struct csr_roam_info *roam_info)
 {
 	tDot11fIEHTInfo *roam_ht_ops = &roam_info->ht_operation;
 	struct ieee80211_ht_operation *hdd_ht_ops =
@@ -776,7 +776,7 @@
  * Return: None
  */
 static void hdd_copy_vht_operation(struct hdd_station_ctx *hdd_sta_ctx,
-					      tCsrRoamInfo *roam_info)
+					      struct csr_roam_info *roam_info)
 {
 	tDot11fIEVHTOperation *roam_vht_ops = &roam_info->vht_operation;
 	struct ieee80211_vht_operation *hdd_vht_ops =
@@ -798,7 +798,7 @@
  * Return: None
  */
 static void hdd_save_bss_info(struct hdd_adapter *adapter,
-						tCsrRoamInfo *roam_info)
+						struct csr_roam_info *roam_info)
 {
 	struct hdd_station_ctx *hdd_sta_ctx =
 		WLAN_HDD_GET_STATION_CTX_PTR(adapter);
@@ -850,7 +850,8 @@
  * Return: none
  */
 static void
-hdd_conn_save_connect_info(struct hdd_adapter *adapter, tCsrRoamInfo *roam_info,
+hdd_conn_save_connect_info(struct hdd_adapter *adapter,
+			   struct csr_roam_info *roam_info,
 			   eCsrRoamBssType eBssType)
 {
 	struct hdd_station_ctx *sta_ctx = WLAN_HDD_GET_STATION_CTX_PTR(adapter);
@@ -953,7 +954,7 @@
 static void
 hdd_send_ft_assoc_response(struct net_device *dev,
 			   struct hdd_adapter *adapter,
-			   tCsrRoamInfo *pCsrRoamInfo)
+			   struct csr_roam_info *pCsrRoamInfo)
 {
 	union iwreq_data wrqu;
 	char *buff;
@@ -1117,7 +1118,7 @@
 static void
 hdd_send_new_ap_channel_info(struct net_device *dev,
 			     struct hdd_adapter *adapter,
-			     tCsrRoamInfo *pCsrRoamInfo)
+			     struct csr_roam_info *pCsrRoamInfo)
 {
 	union iwreq_data wrqu;
 	struct bss_description *descriptor = pCsrRoamInfo->pBssDesc;
@@ -1150,7 +1151,7 @@
  */
 static void
 hdd_send_update_beacon_ies_event(struct hdd_adapter *adapter,
-				  tCsrRoamInfo *pCsrRoamInfo)
+				 struct csr_roam_info *pCsrRoamInfo)
 {
 	union iwreq_data wrqu;
 	u8 *beacon_ies;
@@ -1222,7 +1223,7 @@
  * Return: none
  */
 static void hdd_send_association_event(struct net_device *dev,
-				       tCsrRoamInfo *pCsrRoamInfo)
+				       struct csr_roam_info *pCsrRoamInfo)
 {
 	int ret;
 	struct hdd_adapter *adapter = WLAN_HDD_GET_PRIV_PTR(dev);
@@ -1572,7 +1573,7 @@
  * Return: QDF_STATUS enumeration
  */
 static QDF_STATUS hdd_dis_connect_handler(struct hdd_adapter *adapter,
-					  tCsrRoamInfo *roam_info,
+					  struct csr_roam_info *roam_info,
 					  uint32_t roamId,
 					  eRoamCmdStatus roamStatus,
 					  eCsrRoamResult roamResult)
@@ -1914,7 +1915,7 @@
  * Return: QDF_STATUS enumeration
  */
 QDF_STATUS hdd_roam_register_sta(struct hdd_adapter *adapter,
-					tCsrRoamInfo *roam_info,
+					struct csr_roam_info *roam_info,
 					uint8_t staId,
 					struct qdf_mac_addr *pPeerMacAddress,
 					struct bss_description *pBssDesc)
@@ -2053,7 +2054,7 @@
 #if defined(WLAN_FEATURE_ROAM_OFFLOAD)
 #if defined(WLAN_FEATURE_FILS_SK)
 void hdd_save_gtk_params(struct hdd_adapter *adapter,
-			 tCsrRoamInfo *csr_roam_info, bool is_reassoc)
+			 struct csr_roam_info *csr_roam_info, bool is_reassoc)
 {
 	uint8_t *kek;
 	uint32_t kek_len;
@@ -2078,7 +2079,7 @@
 }
 #else
 void hdd_save_gtk_params(struct hdd_adapter *adapter,
-			 tCsrRoamInfo *csr_roam_info, bool is_reassoc)
+			 struct csr_roam_info *csr_roam_info, bool is_reassoc)
 {
 	uint8_t *kek;
 	uint32_t kek_len;
@@ -2108,7 +2109,7 @@
  * Return: none
  */
 static void hdd_send_re_assoc_event(struct net_device *dev,
-	struct hdd_adapter *adapter, tCsrRoamInfo *pCsrRoamInfo,
+	struct hdd_adapter *adapter, struct csr_roam_info *pCsrRoamInfo,
 	uint8_t *reqRsnIe, uint32_t reqRsnLength)
 {
 	unsigned int len = 0;
@@ -2260,7 +2261,7 @@
  * Return: roam sync status if roaming offloaded else false
  */
 #ifdef WLAN_FEATURE_ROAM_OFFLOAD
-bool hdd_is_roam_sync_in_progress(tCsrRoamInfo *roaminfo)
+bool hdd_is_roam_sync_in_progress(struct csr_roam_info *roaminfo)
 {
 	if (roaminfo)
 		return roaminfo->roamSynchInProgress;
@@ -2281,7 +2282,7 @@
  * Return: sta_id (HDD_WLAN_INVALID_STA_ID if peer not found).
  */
 static uint8_t hdd_get_ibss_peer_staid(struct hdd_station_ctx *hddstactx,
-				       tCsrRoamInfo *roaminfo)
+				       struct csr_roam_info *roaminfo)
 {
 	uint8_t staid = HDD_WLAN_INVALID_STA_ID;
 	QDF_STATUS status;
@@ -2312,7 +2313,7 @@
  * Return: 0 on success and errno on failure
  */
 static int hdd_change_sta_state_authenticated(struct hdd_adapter *adapter,
-						 tCsrRoamInfo *roaminfo)
+						 struct csr_roam_info *roaminfo)
 {
 	QDF_STATUS status;
 	uint32_t timeout;
@@ -2386,7 +2387,8 @@
  * Return: None
  */
 static void hdd_change_peer_state_after_set_key(struct hdd_adapter *adapter,
-			tCsrRoamInfo *roaminfo, eCsrRoamResult roam_result)
+						struct csr_roam_info *roaminfo,
+						eCsrRoamResult roam_result)
 {
 	struct hdd_station_ctx *hdd_sta_ctx =
 		WLAN_HDD_GET_STATION_CTX_PTR(adapter);
@@ -2455,11 +2457,12 @@
  *
  * Return: QDF_STATUS enumeration
  */
-static QDF_STATUS hdd_roam_set_key_complete_handler(struct hdd_adapter *adapter,
-						    tCsrRoamInfo *roam_info,
-						    uint32_t roamId,
-						    eRoamCmdStatus roamStatus,
-						    eCsrRoamResult roamResult)
+static QDF_STATUS
+hdd_roam_set_key_complete_handler(struct hdd_adapter *adapter,
+				  struct csr_roam_info *roam_info,
+				  uint32_t roamId,
+				  eRoamCmdStatus roamStatus,
+				  eCsrRoamResult roamResult)
 {
 	eCsrEncryptionType connectedCipherAlgo;
 	bool fConnected = false;
@@ -2502,7 +2505,7 @@
 {
 	QDF_STATUS qdf_ret_status = QDF_STATUS_SUCCESS;
 	struct hdd_station_ctx *sta_ctx = WLAN_HDD_GET_STATION_CTX_PTR(adapter);
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 
 	roamInfo.fAuthRequired = false;
 	qdf_mem_copy(roamInfo.bssid.bytes,
@@ -2559,7 +2562,7 @@
  */
 static QDF_STATUS
 hdd_association_completion_handler(struct hdd_adapter *adapter,
-				   tCsrRoamInfo *roam_info,
+				   struct csr_roam_info *roam_info,
 				   uint32_t roamId,
 				   eRoamCmdStatus roamStatus,
 				   eCsrRoamResult roamResult)
@@ -3243,7 +3246,7 @@
  * Return: none
  */
 static void hdd_roam_ibss_indication_handler(struct hdd_adapter *adapter,
-					     tCsrRoamInfo *roam_info,
+					     struct csr_roam_info *roam_info,
 					     uint32_t roamId,
 					     eRoamCmdStatus roamStatus,
 					     eCsrRoamResult roamResult)
@@ -3512,7 +3515,7 @@
  * Return: QDF_STATUS enumeration
  */
 static QDF_STATUS roam_ibss_connect_handler(struct hdd_adapter *adapter,
-					    tCsrRoamInfo *roam_info)
+					    struct csr_roam_info *roam_info)
 {
 	struct cfg80211_bss *bss;
 	/*
@@ -3554,7 +3557,7 @@
  */
 static void
 hdd_roam_mic_error_indication_handler(struct hdd_adapter *adapter,
-				      tCsrRoamInfo *roam_info)
+				      struct csr_roam_info *roam_info)
 {
 	struct hdd_station_ctx *sta_ctx = WLAN_HDD_GET_STATION_CTX_PTR(adapter);
 	tSirMicFailureInfo *mic_failure_info;
@@ -3587,7 +3590,7 @@
  */
 static QDF_STATUS
 roam_roam_connect_status_update_handler(struct hdd_adapter *adapter,
-					tCsrRoamInfo *roam_info,
+					struct csr_roam_info *roam_info,
 					uint32_t roamId,
 					eRoamCmdStatus roamStatus,
 					eCsrRoamResult roamResult)
@@ -3832,7 +3835,7 @@
 
 static inline QDF_STATUS
 hdd_roam_tdls_status_update_handler(struct hdd_adapter *adapter,
-				    tCsrRoamInfo *roam_info,
+				    struct csr_roam_info *roam_info,
 				    uint32_t roamId,
 				    eRoamCmdStatus roamStatus,
 				    eCsrRoamResult roamResult)
@@ -3973,7 +3976,8 @@
  * Return: none
  */
 static void
-hdd_indicate_cckm_pre_auth(struct hdd_adapter *adapter, tCsrRoamInfo *roam_info)
+hdd_indicate_cckm_pre_auth(struct hdd_adapter *adapter,
+			   struct csr_roam_info *roam_info)
 {
 	union iwreq_data wrqu;
 	char buf[IW_CUSTOM_MAX + 1];
@@ -4020,7 +4024,7 @@
  */
 static void
 hdd_indicate_ese_adj_ap_rep_ind(struct hdd_adapter *adapter,
-				tCsrRoamInfo *roam_info)
+				struct csr_roam_info *roam_info)
 {
 	union iwreq_data wrqu;
 	char buf[IW_CUSTOM_MAX + 1];
@@ -4096,7 +4100,7 @@
  */
 static void
 hdd_indicate_ese_bcn_report_ind(const struct hdd_adapter *adapter,
-				const tCsrRoamInfo *roam_info)
+				const struct csr_roam_info *roam_info)
 {
 	union iwreq_data wrqu;
 	char buf[IW_CUSTOM_MAX];
@@ -4333,7 +4337,7 @@
  * Return: None
  */
 static void hdd_roam_channel_switch_handler(struct hdd_adapter *adapter,
-				tCsrRoamInfo *roam_info)
+					    struct csr_roam_info *roam_info)
 {
 	struct hdd_chan_change_params chan_change;
 	struct cfg80211_bss *bss;
@@ -4387,7 +4391,8 @@
  * Return: QDF_STATUS enumeration
  */
 QDF_STATUS
-hdd_sme_roam_callback(void *pContext, tCsrRoamInfo *roam_info, uint32_t roamId,
+hdd_sme_roam_callback(void *pContext, struct csr_roam_info *roam_info,
+		      uint32_t roamId,
 		      eRoamCmdStatus roamStatus, eCsrRoamResult roamResult)
 {
 	QDF_STATUS qdf_ret_status = QDF_STATUS_SUCCESS;
diff --git a/core/hdd/src/wlan_hdd_cfg80211.c b/core/hdd/src/wlan_hdd_cfg80211.c
index 816f5a2..22b44b9 100644
--- a/core/hdd/src/wlan_hdd_cfg80211.c
+++ b/core/hdd/src/wlan_hdd_cfg80211.c
@@ -5580,8 +5580,9 @@
  *
  * Return: zero on success, error code on failure
  */
-static int wlan_hdd_add_fils_params_roam_auth_event(struct sk_buff *skb,
-						    tCsrRoamInfo *roam_info)
+static int
+wlan_hdd_add_fils_params_roam_auth_event(struct sk_buff *skb,
+					 struct csr_roam_info *roam_info)
 {
 	if (roam_info->pmk_len &&
 	    nla_put(skb, QCA_WLAN_VENDOR_ATTR_ROAM_AUTH_PMK,
@@ -5610,9 +5611,9 @@
 	return 0;
 }
 #else
-static inline int wlan_hdd_add_fils_params_roam_auth_event(struct sk_buff *skb,
-							   tCsrRoamInfo
-							   *roam_info)
+static inline int
+wlan_hdd_add_fils_params_roam_auth_event(struct sk_buff *skb,
+					 struct csr_roam_info *roam_info)
 {
 	return 0;
 }
@@ -5648,7 +5649,7 @@
  */
 int wlan_hdd_send_roam_auth_event(struct hdd_adapter *adapter, uint8_t *bssid,
 		uint8_t *req_rsn_ie, uint32_t req_rsn_len, uint8_t *rsp_rsn_ie,
-		uint32_t rsp_rsn_len, tCsrRoamInfo *roam_info_ptr)
+		uint32_t rsp_rsn_len, struct csr_roam_info *roam_info_ptr)
 {
 	struct hdd_context *hdd_ctx_ptr = WLAN_HDD_GET_CTX(adapter);
 	struct sk_buff *skb = NULL;
@@ -15137,8 +15138,9 @@
  *
  * Return: struct cfg80211_bss pointer
  */
-struct cfg80211_bss *wlan_hdd_cfg80211_update_bss_db(struct hdd_adapter *adapter,
-						     tCsrRoamInfo *roam_info)
+struct cfg80211_bss *
+wlan_hdd_cfg80211_update_bss_db(struct hdd_adapter *adapter,
+				struct csr_roam_info *roam_info)
 {
 	tCsrRoamConnectedProfile roamProfile;
 	tHalHandle hHal = WLAN_HDD_GET_HAL_CTX(adapter);
@@ -15274,7 +15276,7 @@
  * Return: 0 for success, non-zero for failure
  */
 int wlan_hdd_cfg80211_pmksa_candidate_notify(struct hdd_adapter *adapter,
-					     tCsrRoamInfo *roam_info,
+					     struct csr_roam_info *roam_info,
 					     int index, bool preauth)
 {
 	struct net_device *dev = adapter->dev;
@@ -15306,8 +15308,9 @@
  * Return: QDF status
  */
 #define MAX_LFR_METRICS_EVENT_LENGTH 100
-QDF_STATUS wlan_hdd_cfg80211_roam_metrics_preauth(struct hdd_adapter *adapter,
-						  tCsrRoamInfo *roam_info)
+QDF_STATUS
+wlan_hdd_cfg80211_roam_metrics_preauth(struct hdd_adapter *adapter,
+				       struct csr_roam_info *roam_info)
 {
 	unsigned char metrics_notification[MAX_LFR_METRICS_EVENT_LENGTH + 1];
 	union iwreq_data wrqu;
@@ -15349,7 +15352,7 @@
  */
 QDF_STATUS
 wlan_hdd_cfg80211_roam_metrics_preauth_status(struct hdd_adapter *adapter,
-					      tCsrRoamInfo *roam_info,
+					      struct csr_roam_info *roam_info,
 					      bool preauth_status)
 {
 	unsigned char metrics_notification[MAX_LFR_METRICS_EVENT_LENGTH + 1];
@@ -15397,8 +15400,9 @@
  *
  * Return: QDF status
  */
-QDF_STATUS wlan_hdd_cfg80211_roam_metrics_handover(struct hdd_adapter *adapter,
-						   tCsrRoamInfo *roam_info)
+QDF_STATUS
+wlan_hdd_cfg80211_roam_metrics_handover(struct hdd_adapter *adapter,
+					struct csr_roam_info *roam_info)
 {
 	unsigned char metrics_notification[MAX_LFR_METRICS_EVENT_LENGTH + 1];
 	union iwreq_data wrqu;
diff --git a/core/hdd/src/wlan_hdd_cfg80211.h b/core/hdd/src/wlan_hdd_cfg80211.h
index 9ed38ca..9c866e0 100644
--- a/core/hdd/src/wlan_hdd_cfg80211.h
+++ b/core/hdd/src/wlan_hdd_cfg80211.h
@@ -211,29 +211,32 @@
 #define CFG_PROPAGATION_DELAY_BASE             (64)
 #define CFG_AGG_RETRY_MIN                      (5)
 
-struct cfg80211_bss *wlan_hdd_cfg80211_update_bss_db(struct hdd_adapter *adapter,
-						tCsrRoamInfo *roam_info);
+struct cfg80211_bss *
+wlan_hdd_cfg80211_update_bss_db(struct hdd_adapter *adapter,
+				struct csr_roam_info *roam_info);
 
 int wlan_hdd_cfg80211_pmksa_candidate_notify(struct hdd_adapter *adapter,
-					tCsrRoamInfo *roam_info,
+					struct csr_roam_info *roam_info,
 					int index, bool preauth);
 
 #ifdef FEATURE_WLAN_LFR_METRICS
-QDF_STATUS wlan_hdd_cfg80211_roam_metrics_preauth(struct hdd_adapter *adapter,
-						tCsrRoamInfo *roam_info);
+QDF_STATUS
+wlan_hdd_cfg80211_roam_metrics_preauth(struct hdd_adapter *adapter,
+				       struct csr_roam_info *roam_info);
 
-QDF_STATUS wlan_hdd_cfg80211_roam_metrics_preauth_status(struct hdd_adapter *
-							 adapter,
-							 tCsrRoamInfo *
-							 roam_info,
-							 bool preauth_status);
+QDF_STATUS
+wlan_hdd_cfg80211_roam_metrics_preauth_status(struct hdd_adapter *adapter,
+					      struct csr_roam_info *roam_info,
+					      bool preauth_status);
 
-QDF_STATUS wlan_hdd_cfg80211_roam_metrics_handover(struct hdd_adapter *adapter,
-						   tCsrRoamInfo *roam_info);
+QDF_STATUS
+wlan_hdd_cfg80211_roam_metrics_handover(struct hdd_adapter *adapter,
+					struct csr_roam_info *roam_info);
 #endif
 
 #ifdef FEATURE_WLAN_WAPI
-void wlan_hdd_cfg80211_set_key_wapi(struct hdd_adapter *adapter, uint8_t key_index,
+void wlan_hdd_cfg80211_set_key_wapi(struct hdd_adapter *adapter,
+				    uint8_t key_index,
 				    const uint8_t *mac_addr, const uint8_t *key,
 				    int key_Len);
 #endif
@@ -333,9 +336,11 @@
  *
  * Return: 0 on success or failure reason
  */
-int wlan_hdd_send_hang_reason_event(struct hdd_context *hdd_ctx, uint32_t reason);
+int wlan_hdd_send_hang_reason_event(struct hdd_context *hdd_ctx,
+				    uint32_t reason);
 
-int wlan_hdd_send_avoid_freq_for_dnbs(struct hdd_context *hdd_ctx, uint8_t op_chan);
+int wlan_hdd_send_avoid_freq_for_dnbs(struct hdd_context *hdd_ctx,
+				      uint8_t op_chan);
 
 #ifdef FEATURE_WLAN_EXTSCAN
 void wlan_hdd_cfg80211_extscan_callback(void *ctx,
@@ -357,25 +362,26 @@
 void hdd_rssi_threshold_breached(void *hddctx,
 				 struct rssi_breach_event *data);
 
-struct cfg80211_bss *wlan_hdd_cfg80211_update_bss_list(struct hdd_adapter *adapter,
-						tSirMacAddr bssid);
+struct cfg80211_bss *
+wlan_hdd_cfg80211_update_bss_list(struct hdd_adapter *adapter,
+				  tSirMacAddr bssid);
 
 int wlan_hdd_cfg80211_update_bss(struct wiphy *wiphy,
-						struct hdd_adapter *adapter,
-						uint32_t scan_timestamp);
+				 struct hdd_adapter *adapter,
+				 uint32_t scan_timestamp);
 
 void wlan_hdd_cfg80211_acs_ch_select_evt(struct hdd_adapter *adapter);
 
 #ifdef WLAN_FEATURE_ROAM_OFFLOAD
 int wlan_hdd_send_roam_auth_event(struct hdd_adapter *adapter, uint8_t *bssid,
 		uint8_t *req_rsn_ie, uint32_t req_rsn_length, uint8_t
-		*rsp_rsn_ie, uint32_t rsp_rsn_length, tCsrRoamInfo
+		*rsp_rsn_ie, uint32_t rsp_rsn_length, struct csr_roam_info
 		*roam_info_ptr);
 #else
 static inline int wlan_hdd_send_roam_auth_event(struct hdd_adapter *adapter,
 		uint8_t *bssid, uint8_t *req_rsn_ie, uint32_t req_rsn_length,
-		uint8_t *rsp_rsn_ie, uint32_t rsp_rsn_length, tCsrRoamInfo
-		*roam_info_ptr)
+		uint8_t *rsp_rsn_ie, uint32_t rsp_rsn_length,
+		struct csr_roam_info *roam_info_ptr)
 {
 	return 0;
 }
@@ -391,7 +397,8 @@
 int wlan_hdd_enable_dfs_chan_scan(struct hdd_context *hdd_ctx,
 				  bool enable_dfs_channels);
 
-int wlan_hdd_cfg80211_update_band(struct hdd_context *hdd_ctx, struct wiphy *wiphy,
+int wlan_hdd_cfg80211_update_band(struct hdd_context *hdd_ctx,
+				  struct wiphy *wiphy,
 				  eCsrBand eBand);
 
 /**
diff --git a/core/hdd/src/wlan_hdd_main.c b/core/hdd/src/wlan_hdd_main.c
index 8105afa..5bf756a 100644
--- a/core/hdd/src/wlan_hdd_main.c
+++ b/core/hdd/src/wlan_hdd_main.c
@@ -4881,7 +4881,8 @@
 { }
 #endif
 
-void hdd_update_hlp_info(struct net_device *dev, tCsrRoamInfo *roam_info)
+void hdd_update_hlp_info(struct net_device *dev,
+			 struct csr_roam_info *roam_info)
 {
 	struct sk_buff *skb;
 	uint16_t skb_len;
@@ -4965,7 +4966,8 @@
  * Return: None
  */
 static void hdd_connect_done(struct net_device *dev, const u8 *bssid,
-			     struct cfg80211_bss *bss, tCsrRoamInfo *roam_info,
+			     struct cfg80211_bss *bss,
+			     struct csr_roam_info *roam_info,
 			     const u8 *req_ie, size_t req_ie_len,
 			     const u8 *resp_ie, size_t resp_ie_len, u16 status,
 			     gfp_t gfp, bool connect_timeout,
@@ -5016,7 +5018,7 @@
 #else
 static inline void
 hdd_connect_done(struct net_device *dev, const u8 *bssid,
-		 struct cfg80211_bss *bss, tCsrRoamInfo *roam_info,
+		 struct cfg80211_bss *bss, struct csr_roam_info *roam_info,
 		 const u8 *req_ie, size_t req_ie_len,
 		 const u8 *resp_ie, size_t resp_ie_len, u16 status,
 		 gfp_t gfp, bool connect_timeout,
@@ -5051,7 +5053,7 @@
 static int hdd_fils_update_connect_results(struct net_device *dev,
 			const u8 *bssid,
 			struct cfg80211_bss *bss,
-			tCsrRoamInfo *roam_info, const u8 *req_ie,
+			struct csr_roam_info *roam_info, const u8 *req_ie,
 			size_t req_ie_len, const u8 *resp_ie,
 			size_t resp_ie_len, u16 status, gfp_t gfp,
 			bool connect_timeout,
@@ -5070,7 +5072,7 @@
 static inline int hdd_fils_update_connect_results(struct net_device *dev,
 			const u8 *bssid,
 			struct cfg80211_bss *bss,
-			tCsrRoamInfo *roam_info, const u8 *req_ie,
+			struct csr_roam_info *roam_info, const u8 *req_ie,
 			size_t req_ie_len, const u8 *resp_ie,
 			size_t resp_ie_len, u16 status, gfp_t gfp,
 			bool connect_timeout,
@@ -5100,7 +5102,7 @@
  * Return: Void
  */
 void hdd_connect_result(struct net_device *dev, const u8 *bssid,
-			tCsrRoamInfo *roam_info, const u8 *req_ie,
+			struct csr_roam_info *roam_info, const u8 *req_ie,
 			size_t req_ie_len, const u8 *resp_ie,
 			size_t resp_ie_len, u16 status, gfp_t gfp,
 			bool connect_timeout,
@@ -5141,7 +5143,7 @@
 }
 #else
 void hdd_connect_result(struct net_device *dev, const u8 *bssid,
-			tCsrRoamInfo *roam_info, const u8 *req_ie,
+			struct csr_roam_info *roam_info, const u8 *req_ie,
 			size_t req_ie_len, const u8 *resp_ie,
 			size_t resp_ie_len, u16 status, gfp_t gfp,
 			bool connect_timeout,
diff --git a/core/hdd/src/wlan_hdd_nan_datapath.c b/core/hdd/src/wlan_hdd_nan_datapath.c
index b6b15e8..808330d 100644
--- a/core/hdd/src/wlan_hdd_nan_datapath.c
+++ b/core/hdd/src/wlan_hdd_nan_datapath.c
@@ -881,7 +881,7 @@
 	uint32_t create_reason = NDP_NAN_DATA_IFACE_CREATE_FAILED;
 	struct hdd_station_ctx *sta_ctx = WLAN_HDD_GET_STATION_CTX_PTR(adapter);
 	struct qdf_mac_addr bc_mac_addr = QDF_MAC_ADDR_BROADCAST_INITIALIZER;
-	tCsrRoamInfo *roam_info;
+	struct csr_roam_info *roam_info;
 	struct bss_description tmp_bss_descp = {0};
 
 	ENTER();
@@ -1242,7 +1242,7 @@
 	struct sme_ndp_peer_ind *new_peer_ind = ind_params;
 	struct hdd_context *hdd_ctx = WLAN_HDD_GET_CTX(adapter);
 	struct bss_description tmp_bss_descp = {0};
-	tCsrRoamInfo *roam_info;
+	struct csr_roam_info *roam_info;
 	struct nan_datapath_ctx *ndp_ctx = WLAN_HDD_GET_NDP_CTX_PTR(adapter);
 	struct hdd_station_ctx *sta_ctx = WLAN_HDD_GET_STATION_CTX_PTR(adapter);
 
@@ -1843,8 +1843,9 @@
  * Return: none
  */
 void hdd_ndp_event_handler(struct hdd_adapter *adapter,
-	tCsrRoamInfo *roam_info, uint32_t roam_id, eRoamCmdStatus roam_status,
-	eCsrRoamResult roam_result)
+			   struct csr_roam_info *roam_info,
+			   uint32_t roam_id, eRoamCmdStatus roam_status,
+			   eCsrRoamResult roam_result)
 {
 	if (roam_status == eCSR_ROAM_NDP_STATUS_UPDATE) {
 		switch (roam_result) {
@@ -1897,8 +1898,9 @@
 }
 #else
 void hdd_ndp_event_handler(struct hdd_adapter *adapter,
-	tCsrRoamInfo *roam_info, uint32_t roam_id, eRoamCmdStatus roam_status,
-	eCsrRoamResult roam_result)
+			   struct csr_roam_info *roam_info,
+			   uint32_t roam_id, eRoamCmdStatus roam_status,
+			   eCsrRoamResult roam_result)
 {
 	bool success;
 	struct wlan_objmgr_psoc *psoc = wlan_vdev_get_psoc(adapter->hdd_vdev);
@@ -2281,7 +2283,7 @@
 void hdd_ndi_drv_ndi_create_rsp_handler(uint8_t vdev_id,
 				struct nan_datapath_inf_create_rsp *ndi_rsp)
 {
-	tCsrRoamInfo roam_info = {0};
+	struct csr_roam_info roam_info = {0};
 	struct bss_description tmp_bss_descp = {0};
 	struct hdd_context *hdd_ctx = cds_get_context(QDF_MODULE_ID_HDD);
 	struct hdd_adapter *adapter = hdd_get_adapter_by_vdev(hdd_ctx, vdev_id);
@@ -2356,7 +2358,7 @@
 	struct hdd_context *hdd_ctx = cds_get_context(QDF_MODULE_ID_HDD);
 	struct hdd_adapter *adapter = hdd_get_adapter_by_vdev(hdd_ctx, vdev_id);
 	struct bss_description tmp_bss_descp = {0};
-	tCsrRoamInfo roam_info = {0};
+	struct csr_roam_info roam_info = {0};
 	struct hdd_station_ctx *sta_ctx = WLAN_HDD_GET_STATION_CTX_PTR(adapter);
 
 	ENTER();
diff --git a/core/hdd/src/wlan_hdd_nan_datapath.h b/core/hdd/src/wlan_hdd_nan_datapath.h
index 59c67c5..e4c951a 100644
--- a/core/hdd/src/wlan_hdd_nan_datapath.h
+++ b/core/hdd/src/wlan_hdd_nan_datapath.h
@@ -213,8 +213,9 @@
 void hdd_nan_datapath_target_config(struct hdd_context *hdd_ctx,
 						struct wma_tgt_cfg *cfg);
 void hdd_ndp_event_handler(struct hdd_adapter *adapter,
-	tCsrRoamInfo *roam_info, uint32_t roam_id, eRoamCmdStatus roam_status,
-	eCsrRoamResult roam_result);
+			   struct csr_roam_info *roam_info,
+			   uint32_t roam_id, eRoamCmdStatus roam_status,
+			   eCsrRoamResult roam_result);
 int wlan_hdd_cfg80211_process_ndp_cmd(struct wiphy *wiphy,
 	struct wireless_dev *wdev, const void *data, int data_len);
 int hdd_init_nan_data_mode(struct hdd_adapter *adapter);
@@ -228,8 +229,10 @@
 {
 }
 static inline void hdd_ndp_event_handler(struct hdd_adapter *adapter,
-	tCsrRoamInfo *roam_info, uint32_t roam_id, eRoamCmdStatus roam_status,
-	eCsrRoamResult roam_result)
+					 struct csr_roam_info *roam_info,
+					 uint32_t roam_id,
+					 eRoamCmdStatus roam_status,
+					 eCsrRoamResult roam_result)
 {
 }
 static inline int wlan_hdd_cfg80211_process_ndp_cmd(struct wiphy *wiphy,
diff --git a/core/hdd/src/wlan_hdd_wmm.c b/core/hdd/src/wlan_hdd_wmm.c
index b6a50a6..101aea2 100644
--- a/core/hdd/src/wlan_hdd_wmm.c
+++ b/core/hdd/src/wlan_hdd_wmm.c
@@ -1795,7 +1795,8 @@
  * Return: QDF_STATUS enumeration
  */
 QDF_STATUS hdd_wmm_assoc(struct hdd_adapter *adapter,
-			 tCsrRoamInfo *roam_info, eCsrRoamBssType eBssType)
+			 struct csr_roam_info *roam_info,
+			 eCsrRoamBssType eBssType)
 {
 	uint8_t uapsdMask;
 	QDF_STATUS status;
@@ -1913,7 +1914,8 @@
  * Return: QDF_STATUS enumeration
  */
 QDF_STATUS hdd_wmm_connect(struct hdd_adapter *adapter,
-			   tCsrRoamInfo *roam_info, eCsrRoamBssType eBssType)
+			   struct csr_roam_info *roam_info,
+			   eCsrRoamBssType eBssType)
 {
 	int ac;
 	bool qap;
diff --git a/core/sap/src/sap_fsm.c b/core/sap/src/sap_fsm.c
index 99ed82f8..7a2aa02 100644
--- a/core/sap/src/sap_fsm.c
+++ b/core/sap/src/sap_fsm.c
@@ -2299,7 +2299,7 @@
  * Return: QDF_STATUS
  */
 QDF_STATUS sap_signal_hdd_event(struct sap_context *sap_ctx,
-		tCsrRoamInfo *csr_roaminfo, eSapHddEvent sap_hddevent,
+		struct csr_roam_info *csr_roaminfo, eSapHddEvent sap_hddevent,
 		void *context)
 {
 	QDF_STATUS qdf_status = QDF_STATUS_SUCCESS;
@@ -2894,7 +2894,8 @@
 
    SIDE EFFECTS
    ============================================================================*/
-static QDF_STATUS sap_cac_end_notify(tHalHandle hHal, tCsrRoamInfo *roamInfo)
+static QDF_STATUS sap_cac_end_notify(tHalHandle hHal,
+				     struct csr_roam_info *roamInfo)
 {
 	uint8_t intf;
 	tpAniSirGlobal pMac = PMAC_STRUCT(hHal);
@@ -3244,7 +3245,8 @@
 			tHalHandle hal)
 {
 	uint32_t msg = sap_event->event;
-	tCsrRoamInfo *roam_info = (tCsrRoamInfo *) (sap_event->params);
+	struct csr_roam_info *roam_info =
+		(struct csr_roam_info *) (sap_event->params);
 	QDF_STATUS qdf_status = QDF_STATUS_E_FAILURE;
 
 	if (msg == eSAP_DFS_CHANNEL_CAC_START) {
@@ -3350,7 +3352,8 @@
 			tHalHandle hal)
 {
 	uint32_t msg = sap_event->event;
-	tCsrRoamInfo *roam_info = (tCsrRoamInfo *) (sap_event->params);
+	struct csr_roam_info *roam_info =
+		(struct csr_roam_info *) (sap_event->params);
 	tSapDfsInfo *sap_dfs_info;
 	QDF_STATUS qdf_status = QDF_STATUS_E_FAILURE;
 	uint8_t is_dfs = false;
diff --git a/core/sap/src/sap_internal.h b/core/sap/src/sap_internal.h
index 8174924..4b41f17 100644
--- a/core/sap/src/sap_internal.h
+++ b/core/sap/src/sap_internal.h
@@ -324,7 +324,7 @@
 QDF_STATUS
 wlansap_roam_callback
 	(void *pContext,
-	tCsrRoamInfo *pCsrRoamInfo,
+	struct csr_roam_info *pCsrRoamInfo,
 	uint32_t roamId,
 	eRoamCmdStatus roamStatus, eCsrRoamResult roamResult);
 
@@ -336,7 +336,7 @@
 
 QDF_STATUS
 sap_signal_hdd_event(struct sap_context *sapContext,
-		  tCsrRoamInfo *pCsrRoamInfo,
+		  struct csr_roam_info *pCsrRoamInfo,
 		  eSapHddEvent sapHddevent, void *);
 
 QDF_STATUS sap_fsm(struct sap_context *sapContext, ptWLAN_SAPEvent sapEvent);
diff --git a/core/sme/inc/csr_api.h b/core/sme/inc/csr_api.h
index 2ffd1cc..e018186 100644
--- a/core/sme/inc/csr_api.h
+++ b/core/sme/inc/csr_api.h
@@ -540,10 +540,10 @@
 	eCSR_ROAM_RESULT_SUCCESS = eCSR_ROAM_RESULT_NONE,
 	/*
 	 * If roamStatus is eCSR_ROAM_ASSOCIATION_COMPLETION,
-	 * tCsrRoamInfo's pBssDesc may pass back
+	 * struct csr_roam_info's pBssDesc may pass back
 	 */
 	eCSR_ROAM_RESULT_FAILURE,
-	/* Pass back pointer to tCsrRoamInfo */
+	/* Pass back pointer to struct csr_roam_info */
 	eCSR_ROAM_RESULT_ASSOCIATED,
 	eCSR_ROAM_RESULT_NOT_ASSOCIATED,
 	eCSR_ROAM_RESULT_MIC_FAILURE,
@@ -552,7 +552,7 @@
 	eCSR_ROAM_RESULT_DEAUTH_IND,
 	eCSR_ROAM_RESULT_CAP_CHANGED,
 	/*
-	 * This means we starts an IBSS tCsrRoamInfo's
+	 * This means we starts an IBSS struct csr_roam_info's
 	 * pBssDesc may pass back
 	 */
 	eCSR_ROAM_RESULT_IBSS_STARTED,
@@ -562,11 +562,11 @@
 	eCSR_ROAM_RESULT_IBSS_CONNECT,
 	eCSR_ROAM_RESULT_IBSS_INACTIVE,
 	/*
-	 * If roamStatus is eCSR_ROAM_ASSOCIATION_COMPLETION
-	 * tCsrRoamInfo's pBssDesc may pass back and the peer's MAC address
-	 * in peerMacOrBssid. If roamStatus is eCSR_ROAM_IBSS_IND,
-	 * the peer's MAC address in peerMacOrBssid and a beacon frame
-	 * of the IBSS in pbFrames
+	 * If roamStatus is eCSR_ROAM_ASSOCIATION_COMPLETION struct
+	 * csr_roam_info's pBssDesc may pass back and the peer's MAC
+	 * address in peerMacOrBssid. If roamStatus is
+	 * eCSR_ROAM_IBSS_IND, the peer's MAC address in
+	 * peerMacOrBssid and a beacon frame of the IBSS in pbFrames
 	 */
 	eCSR_ROAM_RESULT_IBSS_NEW_PEER,
 	/*
@@ -1374,7 +1374,7 @@
 #define CSR_ROAM_AUTH_STATUS_AUTHENTICATED  0x2
 #endif
 
-typedef struct csr_roam_info {
+struct csr_roam_info {
 	tCsrRoamProfile *pProfile;
 	tSirBssDescription *pBssDesc;
 	uint32_t nBeaconLength;
@@ -1507,7 +1507,7 @@
 	uint16_t fils_seq_num;
 	struct fils_join_rsp_params *fils_join_rsp;
 #endif
-} tCsrRoamInfo;
+};
 
 typedef struct tagCsrFreqScanInfo {
 	uint32_t nStartFreq;    /* in unit of MHz */
@@ -1712,7 +1712,7 @@
 						uint32_t scanID,
 						eCsrScanStatus status);
 typedef QDF_STATUS (*csr_roam_completeCallback)(void *pContext,
-						tCsrRoamInfo * pParam,
+						struct csr_roam_info *pParam,
 						uint32_t roamId,
 						eRoamCmdStatus roamStatus,
 						eCsrRoamResult roamResult);
@@ -1778,11 +1778,13 @@
 #endif
 typedef void (*tCsrLinkStatusCallback)(uint8_t status, void *pContext);
 #ifdef FEATURE_WLAN_TDLS
-void csr_roam_fill_tdls_info(tpAniSirGlobal mac_ctx, tCsrRoamInfo *roam_info,
-				tpSirSmeJoinRsp join_rsp);
+void csr_roam_fill_tdls_info(tpAniSirGlobal mac_ctx,
+			     struct csr_roam_info *roam_info,
+			     tpSirSmeJoinRsp join_rsp);
 #else
-static inline void csr_roam_fill_tdls_info(tpAniSirGlobal mac_ctx, tCsrRoamInfo *roam_info,
-				tpSirSmeJoinRsp join_rsp)
+static inline void csr_roam_fill_tdls_info(tpAniSirGlobal mac_ctx,
+					   struct csr_roam_info *roam_info,
+					   tpSirSmeJoinRsp join_rsp)
 {}
 #endif
 void csr_packetdump_timer_stop(void);
diff --git a/core/sme/inc/sme_api.h b/core/sme/inc/sme_api.h
index bc15e24..0836a02 100644
--- a/core/sme/inc/sme_api.h
+++ b/core/sme/inc/sme_api.h
@@ -1357,9 +1357,9 @@
  * Return: true if ESE Association, false otherwise.
  */
 #ifdef FEATURE_WLAN_ESE
-bool sme_roam_is_ese_assoc(tCsrRoamInfo *roam_info);
+bool sme_roam_is_ese_assoc(struct csr_roam_info *roam_info);
 #else
-static inline bool sme_roam_is_ese_assoc(tCsrRoamInfo *roam_info)
+static inline bool sme_roam_is_ese_assoc(struct csr_roam_info *roam_info)
 {
 	return false;
 }
@@ -1842,7 +1842,7 @@
  *
  * Return: void
  */
-void sme_free_join_rsp_fils_params(tCsrRoamInfo *roam_info);
+void sme_free_join_rsp_fils_params(struct csr_roam_info *roam_info);
 #else
 static inline QDF_STATUS sme_update_fils_config(tHalHandle hal,
 				uint8_t session_id,
@@ -1851,7 +1851,8 @@
 	return QDF_STATUS_SUCCESS;
 }
 
-static inline void sme_free_join_rsp_fils_params(tCsrRoamInfo *roam_info)
+static inline
+void sme_free_join_rsp_fils_params(struct csr_roam_info *roam_info)
 {}
 
 #endif
diff --git a/core/sme/src/common/sme_api.c b/core/sme/src/common/sme_api.c
index 5aa3cb0..fa460b7 100644
--- a/core/sme/src/common/sme_api.c
+++ b/core/sme/src/common/sme_api.c
@@ -1341,7 +1341,7 @@
 		struct scheduler_msg *msg)
 {
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
-	tCsrRoamInfo roam_info = { 0 };
+	struct csr_roam_info roam_info = { 0 };
 	tSirSmeCSAIeTxCompleteRsp *csa_ie_tx_complete_rsp;
 	uint32_t session_id = 0;
 	eRoamCmdStatus roam_status;
@@ -1408,7 +1408,7 @@
 {
 	tpAniSirGlobal pMac = PMAC_STRUCT(hHal);
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
-	tCsrRoamInfo roam_info = { 0 };
+	struct csr_roam_info roam_info = { 0 };
 	uint32_t SessionId = pSmeMgmtFrm->sessionId;
 
 	roam_info.nFrameLength = pSmeMgmtFrm->frameLen;
@@ -1427,7 +1427,7 @@
 {
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
 	tpAniSirGlobal mac = PMAC_STRUCT(hal);
-	tCsrRoamInfo *roamInfo;
+	struct csr_roam_info *roamInfo;
 	eRoamCmdStatus roamStatus;
 	eCsrRoamResult roamResult;
 
@@ -1465,7 +1465,7 @@
 	struct sir_sme_ext_cng_chan_ind *ext_chan_ind;
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
 	uint32_t session_id = 0;
-	tCsrRoamInfo roamInfo = {0};
+	struct csr_roam_info roamInfo = {0};
 	eRoamCmdStatus roam_status;
 	eCsrRoamResult roam_result;
 
@@ -1668,7 +1668,7 @@
 {
 	tpAniSirGlobal pMac = PMAC_STRUCT(hHal);
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
-	tCsrRoamInfo roam_info = { 0 };
+	struct csr_roam_info roam_info = { 0 };
 	uint32_t SessionId = pSmeTsmIeInd->sessionId;
 
 	roam_info.tsmIe.tsid = pSmeTsmIeInd->tsmIe.tsid;
@@ -7023,7 +7023,7 @@
 	sme_release_global_lock(&mac->sme);
 }
 
-void sme_free_join_rsp_fils_params(tCsrRoamInfo *roam_info)
+void sme_free_join_rsp_fils_params(struct csr_roam_info *roam_info)
 {
 	struct fils_join_rsp_params *roam_fils_params;
 
@@ -10629,7 +10629,7 @@
 					   uint16_t msg_type, void *pMsgBuf)
 {
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
-	tCsrRoamInfo proam_info = { 0 };
+	struct csr_roam_info proam_info = { 0 };
 	eCsrRoamResult roamResult;
 	tpSwitchChannelParams pChnlParams = (tpSwitchChannelParams) pMsgBuf;
 	uint32_t SessionId = pChnlParams->peSessionId;
@@ -15033,7 +15033,7 @@
 }
 
 #ifdef FEATURE_WLAN_ESE
-bool sme_roam_is_ese_assoc(tCsrRoamInfo *roam_info)
+bool sme_roam_is_ese_assoc(struct csr_roam_info *roam_info)
 {
 	return roam_info->isESEAssoc;
 }
diff --git a/core/sme/src/csr/csr_api_roam.c b/core/sme/src/csr/csr_api_roam.c
index 0c9b6ce..5bf9e51 100644
--- a/core/sme/src/csr/csr_api_roam.c
+++ b/core/sme/src/csr/csr_api_roam.c
@@ -1821,7 +1821,7 @@
 					struct csr_roam_session *pSession)
 {
 	uint32_t roamTS2 = 0;
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 	tpPESession pSessionEntry = NULL;
 	uint8_t sessionId = CSR_SESSION_ID_INVALID;
 
@@ -3713,7 +3713,7 @@
  * Return: none.
  */
 static void csr_roam_populate_channels(tDot11fBeaconIEs *beacon_ies,
-			tCsrRoamInfo *roam_info,
+			struct csr_roam_info *roam_info,
 			uint8_t *chan1, uint8_t *chan2)
 {
 	ePhyChanBondState phy_state;
@@ -3749,7 +3749,8 @@
 }
 
 QDF_STATUS csr_roam_call_callback(tpAniSirGlobal pMac, uint32_t sessionId,
-				  tCsrRoamInfo *roam_info, uint32_t roamId,
+				  struct csr_roam_info *roam_info,
+				  uint32_t roamId,
 				  eRoamCmdStatus u1, eCsrRoamResult u2)
 {
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
@@ -5363,9 +5364,9 @@
 				tSirBssDescription *pBssDesc, uint32_t roamId)
 {
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 
-	qdf_mem_set(&roamInfo, sizeof(tCsrRoamInfo), 0);
+	qdf_mem_set(&roamInfo, sizeof(struct csr_roam_info), 0);
 	roamInfo.pBssDesc = pBssDesc;
 	status = csr_roam_call_callback(pMac, sessionId, &roamInfo, roamId,
 				eCSR_ROAM_SHOULD_ROAM, eCSR_ROAM_RESULT_NONE);
@@ -5513,7 +5514,8 @@
  * Return: None
  */
 static void csr_roam_join_handle_profile(tpAniSirGlobal mac_ctx,
-		uint32_t session_id, tSmeCmd *cmd, tCsrRoamInfo *roam_info_ptr,
+		uint32_t session_id, tSmeCmd *cmd,
+		struct csr_roam_info *roam_info_ptr,
 		enum csr_join_state *roam_state, tCsrScanResultInfo *result,
 		struct tag_csrscan_result *scan_result)
 {
@@ -5557,7 +5559,7 @@
 			csr_set_abort_roaming_command(mac_ctx, cmd);
 			return;
 		}
-		qdf_mem_set(roam_info_ptr, sizeof(tCsrRoamInfo), 0);
+		qdf_mem_set(roam_info_ptr, sizeof(struct csr_roam_info), 0);
 		if (!scan_result)
 			cmd->u.roamCmd.roamProfile.uapsd_mask = 0;
 		else
@@ -5699,7 +5701,7 @@
 	struct scan_result_list *bss_list =
 		(struct scan_result_list *) cmd->u.roamCmd.hBSSList;
 	bool done = false;
-	tCsrRoamInfo *roam_info = NULL;
+	struct csr_roam_info *roam_info = NULL;
 	uint32_t session_id = cmd->sessionId;
 	struct csr_roam_session *session = CSR_GET_SESSION(mac_ctx, session_id);
 	tCsrRoamProfile *profile = &cmd->u.roamCmd.roamProfile;
@@ -5921,7 +5923,7 @@
  * Return: QDF_STATUS for success or failure.
  */
 static QDF_STATUS csr_roam_trigger_reassociate(
-tpAniSirGlobal mac_ctx, tSmeCmd *cmd, tCsrRoamInfo *roam_info,
+tpAniSirGlobal mac_ctx, tSmeCmd *cmd, struct csr_roam_info *roam_info,
 			struct csr_roam_session *session_ptr,
 				uint32_t session_id)
 {
@@ -5975,7 +5977,7 @@
 QDF_STATUS csr_roam_process_command(tpAniSirGlobal pMac, tSmeCmd *pCommand)
 {
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 	uint32_t sessionId = pCommand->sessionId;
 	struct csr_roam_session *pSession = CSR_GET_SESSION(pMac, sessionId);
 
@@ -6553,7 +6555,7 @@
  * Return: None
  */
 static void csr_update_fils_seq_number(struct csr_roam_session *session,
-					 tCsrRoamInfo *roam_info)
+					 struct csr_roam_info *roam_info)
 {
 	roam_info->is_fils_connection = true;
 	roam_info->fils_seq_num = session->fils_seq_num;
@@ -6561,7 +6563,7 @@
 }
 #else
 static inline void csr_update_fils_seq_number(struct csr_roam_session *session,
-						tCsrRoamInfo *roam_info)
+						struct csr_roam_info *roam_info)
 {}
 #endif
 
@@ -6579,7 +6581,7 @@
 {
 	uint32_t session_id = cmd->sessionId;
 	struct csr_roam_session *session;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	QDF_STATUS status;
 
 	if (!CSR_IS_SESSION_VALID(mac_ctx, session_id)) {
@@ -6603,7 +6605,7 @@
 		csr_set_default_dot11_mode(mac_ctx);
 	}
 
-	qdf_mem_set(&roam_info, sizeof(tCsrRoamInfo), 0);
+	qdf_mem_set(&roam_info, sizeof(struct csr_roam_info), 0);
 	/* Copy FILS sequence number used to be updated to userspace */
 	if (session->is_fils_connection)
 		csr_update_fils_seq_number(session, &roam_info);
@@ -6788,7 +6790,7 @@
 	tCsrRoamProfile *profile = &cmd->u.roamCmd.roamProfile;
 	struct csr_roam_session *session;
 	tSirBssDescription *bss_desc = NULL;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	tSirSmeStartBssRsp *start_bss_rsp = NULL;
 	struct tag_csrscan_result *scan_res = NULL;
 	eRoamCmdStatus roam_status;
@@ -6821,7 +6823,7 @@
 	sme_debug("receives start BSS ok indication");
 	status = QDF_STATUS_E_FAILURE;
 	start_bss_rsp = (tSirSmeStartBssRsp *) context;
-	qdf_mem_set(&roam_info, sizeof(tCsrRoamInfo), 0);
+	qdf_mem_set(&roam_info, sizeof(struct csr_roam_info), 0);
 	if (CSR_IS_IBSS(profile))
 		session->connectState = eCSR_ASSOC_STATE_TYPE_IBSS_DISCONNECTED;
 	else if (CSR_IS_INFRA_AP(profile))
@@ -7001,7 +7003,7 @@
  * Return: QDF_STATUS
  */
 static QDF_STATUS populate_fils_params_join_rsp(tpAniSirGlobal mac_ctx,
-						tCsrRoamInfo *roam_info,
+						struct csr_roam_info *roam_info,
 						tSirSmeJoinRsp *join_rsp)
 {
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
@@ -7086,7 +7088,7 @@
 static void csr_process_fils_join_rsp(tpAniSirGlobal mac_ctx,
 					tCsrRoamProfile *profile,
 					uint32_t session_id,
-					tCsrRoamInfo *roam_info,
+					struct csr_roam_info *roam_info,
 					tSirBssDescription *bss_desc,
 					tSirSmeJoinRsp *join_rsp)
 {
@@ -7136,7 +7138,7 @@
 static inline void csr_process_fils_join_rsp(tpAniSirGlobal mac_ctx,
 						tCsrRoamProfile *profile,
 						uint32_t session_id,
-						tCsrRoamInfo *roam_info,
+						struct csr_roam_info *roam_info,
 						tSirBssDescription *bss_desc,
 						tSirSmeJoinRsp *join_rsp)
 {}
@@ -7172,7 +7174,7 @@
 #endif
 	tCsrRoamConnectedProfile *conn_profile = NULL;
 	tDot11fBeaconIEs *ies_ptr = NULL;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	struct ps_global_info *ps_global_info = &mac_ctx->sme.ps_global_info;
 	tSirSmeJoinRsp *join_rsp = (tSirSmeJoinRsp *) context;
 	uint32_t len;
@@ -7564,7 +7566,7 @@
 {
 	bool release_cmd = true;
 	tSirBssDescription *bss_desc = NULL;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	uint32_t session_id = cmd->sessionId;
 	struct csr_roam_session *session = CSR_GET_SESSION(mac_ctx, session_id);
 	tCsrRoamProfile *profile = &cmd->u.roamCmd.roamProfile;
@@ -7630,7 +7632,7 @@
 			session_id);
 		csr_roam_substate_change(mac_ctx, eCSR_ROAM_SUBSTATE_NONE,
 			session_id);
-		qdf_mem_set(&roam_info, sizeof(tCsrRoamInfo), 0);
+		qdf_mem_set(&roam_info, sizeof(struct csr_roam_info), 0);
 		roam_info.pBssDesc = session->pConnectBssDesc;
 		if (roam_info.pBssDesc)
 			qdf_mem_copy(&roam_info.bssid,
@@ -9283,7 +9285,7 @@
 {
 	tListElem *pEntry;
 	tSmeCmd *pCommand;
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 	uint32_t sessionId;
 	struct csr_roam_session *pSession;
 
@@ -9325,7 +9327,7 @@
 		}
 		return;
 	}
-	qdf_mem_set(&roamInfo, sizeof(tCsrRoamInfo), 0);
+	qdf_mem_set(&roamInfo, sizeof(struct csr_roam_info), 0);
 	roamInfo.pBssDesc = pCommand->u.roamCmd.pLastRoamBss;
 	roamInfo.statusCode = pSession->joinFailStatusCode.statusCode;
 	roamInfo.reasonCode = pSession->joinFailStatusCode.reasonCode;
@@ -9615,7 +9617,7 @@
 	enum csr_roamcomplete_result result;
 	tpCsrNeighborRoamControlInfo pNeighborRoamInfo =
 		&pMac->roam.neighborRoamInfo[pSmeJoinRsp->sessionId];
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 	uint32_t roamId = 0;
 	struct csr_roam_session *csr_session;
 
@@ -9669,7 +9671,7 @@
 			pSmeJoinRsp->statusCode)) {
 			/* Inform HDD to turn off FT flag in HDD */
 			if (pNeighborRoamInfo) {
-				qdf_mem_zero(&roamInfo, sizeof(tCsrRoamInfo));
+				qdf_mem_zero(&roamInfo, sizeof(roamInfo));
 				csr_roam_call_callback(pMac,
 						pSmeJoinRsp->sessionId,
 						&roamInfo, roamId,
@@ -9803,7 +9805,7 @@
 static void
 csr_post_roam_failure(tpAniSirGlobal mac_ctx,
 		      uint32_t session_id,
-		      tCsrRoamInfo *roam_info,
+		      struct csr_roam_info *roam_info,
 		      tCsrScanResultFilter *scan_filter,
 		      tCsrRoamProfile *cur_roam_profile)
 {
@@ -9820,7 +9822,7 @@
 		csr_roam_synch_clean_up(mac_ctx, session_id);
 #endif
 	/* Inform the upper layers that the reassoc failed */
-	qdf_mem_zero(roam_info, sizeof(tCsrRoamInfo));
+	qdf_mem_zero(roam_info, sizeof(struct csr_roam_info));
 	csr_roam_call_callback(mac_ctx, session_id, roam_info, 0,
 			       eCSR_ROAM_FT_REASSOC_FAILED,
 			       eCSR_ROAM_RESULT_SUCCESS);
@@ -9888,7 +9890,7 @@
 						   tSirSmeDisassocRsp *pSmeRsp)
 {
 	tScanResultHandle hBSSList;
-	tCsrRoamInfo *roamInfo;
+	struct csr_roam_info *roamInfo;
 	tCsrScanResultFilter *pScanFilter = NULL;
 	uint32_t roamId = 0;
 	tCsrRoamProfile *pCurRoamProfile = NULL;
@@ -10095,7 +10097,7 @@
 {
 	tSirSmeRsp *pSmeRsp;
 	tSmeIbssPeerInd *pIbssPeerInd;
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 
 	pSmeRsp = (tSirSmeRsp *) pMsgBuf;
 	sme_debug("Message %d[0x%04X] received in substate %s",
@@ -10166,7 +10168,7 @@
 	case eWNI_SME_IBSS_PEER_DEPARTED_IND:
 		pIbssPeerInd = (tSmeIbssPeerInd *) pSmeRsp;
 		sme_err("Peer departed ntf from LIM in joining state");
-		qdf_mem_set(&roamInfo, sizeof(tCsrRoamInfo), 0);
+		qdf_mem_set(&roamInfo, sizeof(struct csr_roam_info), 0);
 		roamInfo.staId = (uint8_t) pIbssPeerInd->staId;
 		roamInfo.ucastSig = (uint8_t) pIbssPeerInd->ucastSig;
 		roamInfo.bcastSig = (uint8_t) pIbssPeerInd->bcastSig;
@@ -10212,13 +10214,13 @@
 	{
 		struct csr_roam_session *pSession;
 		tSirSmeAssocIndToUpperLayerCnf *pUpperLayerAssocCnf;
-		tCsrRoamInfo roamInfo;
-		tCsrRoamInfo *roam_info = NULL;
+		struct csr_roam_info roamInfo;
+		struct csr_roam_info *roam_info = NULL;
 		uint32_t sessionId;
 		QDF_STATUS status;
 
 		sme_debug("ASSOCIATION confirmation can be given to upper layer ");
-		qdf_mem_set(&roamInfo, sizeof(tCsrRoamInfo), 0);
+		qdf_mem_set(&roamInfo, sizeof(struct csr_roam_info), 0);
 		roam_info = &roamInfo;
 		pUpperLayerAssocCnf =
 			(tSirSmeAssocIndToUpperLayerCnf *) pMsgBuf;
@@ -11067,9 +11069,9 @@
 	struct csr_roam_session *session;
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
-	tCsrRoamInfo *roam_info_ptr = NULL;
+	struct csr_roam_info *roam_info_ptr = NULL;
 	tSirSmeAssocInd *pAssocInd;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 
 	qdf_mem_set(&roam_info, sizeof(roam_info), 0);
 	sme_debug("Receive WNI_SME_ASSOC_IND from SME");
@@ -11259,7 +11261,7 @@
 {
 	struct sir_sme_discon_done_ind *discon_ind =
 				(struct sir_sme_discon_done_ind *)(msg_ptr);
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	struct csr_roam_session *session;
 
 	sme_debug("eWNI_SME_DISCONNECT_DONE_IND RC:%d",
@@ -11291,7 +11293,7 @@
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
 	tSirSmeDeauthInd *pDeauthInd;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 
 	qdf_mem_set(&roam_info, sizeof(roam_info), 0);
 	sme_debug("DEAUTHENTICATION Indication from MAC");
@@ -11369,7 +11371,7 @@
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
 	tpSirSmeSwitchChannelInd pSwitchChnInd;
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 
 	/* in case of STA, the SWITCH_CHANNEL originates from its AP */
 	sme_debug("eWNI_SME_SWITCH_CHL_IND from SME");
@@ -11392,7 +11394,7 @@
 				(uint8_t) pSwitchChnInd->newChannelId;
 		}
 
-		qdf_mem_set(&roamInfo, sizeof(tCsrRoamInfo), 0);
+		qdf_mem_set(&roamInfo, sizeof(struct csr_roam_info), 0);
 		roamInfo.chan_info.chan_id = pSwitchChnInd->newChannelId;
 		roamInfo.chan_info.ch_width =
 				pSwitchChnInd->chan_params.ch_width;
@@ -11421,9 +11423,9 @@
 	struct csr_roam_session *session;
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
-	tCsrRoamInfo *roam_info_ptr = NULL;
+	struct csr_roam_info *roam_info_ptr = NULL;
 	tSirSmeDeauthRsp *pDeauthRsp = (tSirSmeDeauthRsp *) msg_ptr;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 
 	qdf_mem_set(&roam_info, sizeof(roam_info), 0);
 	sme_debug("eWNI_SME_DEAUTH_RSP from SME");
@@ -11451,8 +11453,8 @@
 	struct csr_roam_session *session;
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
-	tCsrRoamInfo *roam_info_ptr = NULL;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info *roam_info_ptr = NULL;
+	struct csr_roam_info roam_info;
 	/*
 	 * session id is invalid here so cant use it to access the array
 	 * curSubstate as index
@@ -11514,8 +11516,8 @@
 {
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
-	tCsrRoamInfo *roam_info_ptr = NULL;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info *roam_info_ptr = NULL;
+	struct csr_roam_info roam_info;
 	tpSirSmeMicFailureInd pMicInd = (tpSirSmeMicFailureInd) msg_ptr;
 	eCsrRoamResult result = eCSR_ROAM_RESULT_MIC_ERROR_UNICAST;
 
@@ -11523,7 +11525,7 @@
 	status = csr_roam_get_session_id_from_bssid(mac_ctx,
 				&pMicInd->bssId, &sessionId);
 	if (QDF_IS_STATUS_SUCCESS(status)) {
-		qdf_mem_set(&roam_info, sizeof(tCsrRoamInfo), 0);
+		qdf_mem_set(&roam_info, sizeof(struct csr_roam_info), 0);
 		roam_info.u.pMICFailureInfo = &pMicInd->info;
 		roam_info_ptr = &roam_info;
 		if (pMicInd->info.multicast)
@@ -11543,7 +11545,7 @@
 {
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	tpSirSmeProbeReqInd pProbeReqInd = (tpSirSmeProbeReqInd) msg_ptr;
 
 	qdf_mem_set(&roam_info, sizeof(roam_info), 0);
@@ -11552,7 +11554,7 @@
 	status = csr_roam_get_session_id_from_bssid(mac_ctx,
 			&pProbeReqInd->bssid, &sessionId);
 	if (QDF_IS_STATUS_SUCCESS(status)) {
-		qdf_mem_set(&roam_info, sizeof(tCsrRoamInfo), 0);
+		qdf_mem_set(&roam_info, sizeof(struct csr_roam_info), 0);
 		roam_info.u.pWPSPBCProbeReq = &pProbeReqInd->WPSPBCProbeReq;
 		csr_roam_call_callback(mac_ctx, sessionId, &roam_info,
 				       0, eCSR_ROAM_WPS_PBC_PROBE_REQ_IND,
@@ -11596,9 +11598,9 @@
 	struct csr_roam_session *session;
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
-	tCsrRoamInfo *roam_info_ptr = NULL;
+	struct csr_roam_info *roam_info_ptr = NULL;
 	tSirSmeWmStatusChangeNtf *pStatusChangeMsg;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	tSirSmeApNewCaps *pApNewCaps;
 	eCsrRoamResult result = eCSR_ROAM_RESULT_NONE;
 	tSirMacAddr Broadcastaddr = { 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF };
@@ -11748,9 +11750,9 @@
 	struct csr_roam_session *session;
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
-	tCsrRoamInfo *roam_info_ptr = NULL;
+	struct csr_roam_info *roam_info_ptr = NULL;
 	tSmeIbssPeerInd *pIbssPeerInd = (tSmeIbssPeerInd *) msg_ptr;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 #ifdef FEATURE_WLAN_DIAG_SUPPORT_CSR
 	host_log_ibss_pkt_type *pIbssLog;
 
@@ -11849,7 +11851,7 @@
 					tSirSmeRsp *msg_ptr)
 {
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	tSmeIbssPeerInd *pIbssPeerInd;
 
 	if (NULL == msg_ptr) {
@@ -11927,8 +11929,8 @@
 	struct csr_roam_session *session;
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	QDF_STATUS status;
-	tCsrRoamInfo *roam_info_ptr = NULL;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info *roam_info_ptr = NULL;
+	struct csr_roam_info roam_info;
 	eCsrRoamResult result = eCSR_ROAM_RESULT_NONE;
 	tSirSmeSetContextRsp *pRsp = (tSirSmeSetContextRsp *) msg_ptr;
 
@@ -12049,7 +12051,7 @@
 {
 	uint32_t sessionId = CSR_SESSION_ID_INVALID;
 	tSmeMaxAssocInd *pSmeMaxAssocInd;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 
 	qdf_mem_set(&roam_info, sizeof(roam_info), 0);
 	pSmeMaxAssocInd = (tSmeMaxAssocInd *) msg_ptr;
@@ -12150,8 +12152,8 @@
 
 void csr_call_roaming_completion_callback(tpAniSirGlobal pMac,
 					  struct csr_roam_session *pSession,
-					  tCsrRoamInfo *roam_info,
-					uint32_t roamId,
+					  struct csr_roam_info *roam_info,
+					  uint32_t roamId,
 					  eCsrRoamResult roamResult)
 {
 	if (pSession) {
@@ -12509,7 +12511,7 @@
 }
 
 void csr_roam_completion(tpAniSirGlobal pMac, uint32_t sessionId,
-			 tCsrRoamInfo *roam_info, tSmeCmd *pCommand,
+			 struct csr_roam_info *roam_info, tSmeCmd *pCommand,
 			 eCsrRoamResult roamResult, bool fSuccess)
 {
 	eRoamCmdStatus roamStatus = csr_get_roam_complete_status(pMac,
@@ -12553,7 +12555,7 @@
 	tSirSmeDeauthInd *pDeauthIndMsg = NULL;
 	tSirSmeDisassocInd *pDisassocIndMsg = NULL;
 	eCsrRoamResult result = eCSR_ROAM_RESULT_LOSTLINK;
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 	struct csr_roam_session *pSession = CSR_GET_SESSION(pMac, sessionId);
 
 	if (!pSession) {
@@ -12592,7 +12594,7 @@
 		status = csr_send_mb_deauth_cnf_msg(pMac, pDeauthIndMsg);
 
 	/* prepare to tell HDD to disconnect */
-	qdf_mem_set(&roamInfo, sizeof(tCsrRoamInfo), 0);
+	qdf_mem_set(&roamInfo, sizeof(struct csr_roam_info), 0);
 	roamInfo.statusCode = (tSirResultCodes) pSession->roamingStatusCode;
 	roamInfo.reasonCode = pSession->joinFailStatusCode.reasonCode;
 	if (eWNI_SME_DISASSOC_IND == type) {
@@ -16130,9 +16132,9 @@
 					  uint32_t sessionId)
 {
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 
-	qdf_mem_set(&roamInfo, sizeof(tCsrRoamInfo), 0);
+	qdf_mem_set(&roamInfo, sizeof(struct csr_roam_info), 0);
 	status = csr_roam_call_callback(pMac, sessionId, &roamInfo, 0,
 					eCSR_ROAM_SESSION_OPENED,
 					eCSR_ROAM_RESULT_NONE);
@@ -20649,8 +20651,9 @@
  *
  * Return: None
  */
-void csr_roam_fill_tdls_info(tpAniSirGlobal mac_ctx, tCsrRoamInfo *roam_info,
-				tpSirSmeJoinRsp join_rsp)
+void csr_roam_fill_tdls_info(tpAniSirGlobal mac_ctx,
+			     struct csr_roam_info *roam_info,
+			     tpSirSmeJoinRsp join_rsp)
 {
 	roam_info->tdls_prohibited = join_rsp->tdls_prohibited;
 	roam_info->tdls_chan_swit_prohibited =
@@ -20663,7 +20666,7 @@
 #endif
 
 #if defined(WLAN_FEATURE_FILS_SK) && defined(WLAN_FEATURE_ROAM_OFFLOAD)
-static void csr_copy_fils_join_rsp_roam_info(tCsrRoamInfo *roam_info,
+static void csr_copy_fils_join_rsp_roam_info(struct csr_roam_info *roam_info,
 				      roam_offload_synch_ind *roam_synch_data)
 {
 	struct fils_join_rsp_params *roam_fils_info;
@@ -20685,7 +20688,8 @@
 			roam_fils_info->hlp_data);
 }
 #else
-static inline void csr_copy_fils_join_rsp_roam_info(tCsrRoamInfo *roam_info,
+static inline
+void csr_copy_fils_join_rsp_roam_info(struct csr_roam_info *roam_info,
 				      roam_offload_synch_ind *roam_synch_data)
 {}
 #endif
@@ -20699,7 +20703,7 @@
 	struct csr_roam_session *session = CSR_GET_SESSION(mac_ctx, session_id);
 	tDot11fBeaconIEs *ies_local = NULL;
 	struct ps_global_info *ps_global_info = &mac_ctx->sme.ps_global_info;
-	tCsrRoamInfo *roam_info;
+	struct csr_roam_info *roam_info;
 	tCsrRoamConnectedProfile *conn_profile = NULL;
 	sme_QosAssocInfo assoc_info;
 	tpAddBssParams add_bss_params;
@@ -20809,7 +20813,7 @@
 		ies_local);
 	ps_global_info->remain_in_power_active_till_dhcp = false;
 	session->connectState = eCSR_ASSOC_STATE_TYPE_INFRA_ASSOCIATED;
-	roam_info = qdf_mem_malloc(sizeof(tCsrRoamInfo));
+	roam_info = qdf_mem_malloc(sizeof(struct csr_roam_info));
 	if (NULL == roam_info) {
 		QDF_TRACE(QDF_MODULE_ID_SME, QDF_TRACE_LEVEL_DEBUG,
 			FL("LFR3: Mem Alloc failed for roam info"));
diff --git a/core/sme/src/csr/csr_api_scan.c b/core/sme/src/csr/csr_api_scan.c
index 010d33e..8756141 100644
--- a/core/sme/src/csr/csr_api_scan.c
+++ b/core/sme/src/csr/csr_api_scan.c
@@ -1229,9 +1229,9 @@
 	}
 	/* Only indicate assoc_completion if we indicate assoc_start. */
 	if (session->bRefAssocStartCnt > 0) {
-		tCsrRoamInfo *roam_info = NULL, roamInfo;
+		struct csr_roam_info *roam_info = NULL, roamInfo;
 
-		qdf_mem_set(&roamInfo, sizeof(tCsrRoamInfo), 0);
+		qdf_mem_set(&roamInfo, sizeof(struct csr_roam_info), 0);
 		roam_info = &roamInfo;
 		if (session->scan_info.roambssentry) {
 			struct tag_csrscan_result *pScanResult = GET_BASE_ADDR(
@@ -1402,8 +1402,8 @@
 	tSirMbMsg *pMsg = (tSirMbMsg *) pMsgBuf;
 	struct csr_roam_session *pSession;
 	tSirSmeAssocIndToUpperLayerCnf *pUpperLayerAssocCnf;
-	tCsrRoamInfo roamInfo;
-	tCsrRoamInfo *roam_info = NULL;
+	struct csr_roam_info roamInfo;
+	struct csr_roam_info *roam_info = NULL;
 	uint32_t sessionId;
 
 	if (eWNI_SME_SCAN_RSP == pMsg->type)
@@ -1426,7 +1426,7 @@
 	}
 
 	sme_debug("Scanning: ASSOC cnf can be given to upper layer");
-	qdf_mem_set(&roamInfo, sizeof(tCsrRoamInfo), 0);
+	qdf_mem_set(&roamInfo, sizeof(struct csr_roam_info), 0);
 	roam_info = &roamInfo;
 	pUpperLayerAssocCnf = (tSirSmeAssocIndToUpperLayerCnf *) pMsgBuf;
 	status = csr_roam_get_session_id_from_bssid(pMac,
diff --git a/core/sme/src/csr/csr_host_scan_roam.c b/core/sme/src/csr/csr_host_scan_roam.c
index 2ac046c..d21b6f6 100644
--- a/core/sme/src/csr/csr_host_scan_roam.c
+++ b/core/sme/src/csr/csr_host_scan_roam.c
@@ -584,7 +584,7 @@
 void csr_neighbor_roam_request_handoff(tpAniSirGlobal mac_ctx,
 		uint8_t session_id)
 {
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	tpCsrNeighborRoamControlInfo neighbor_roam_info =
 		&mac_ctx->roam.neighborRoamInfo[session_id];
 	tCsrNeighborRoamBSSInfo handoff_node;
@@ -612,11 +612,11 @@
 		  FL("HANDOFF CANDIDATE BSSID "MAC_ADDRESS_STR),
 		  MAC_ADDR_ARRAY(handoff_node.pBssDescription->bssId));
 
-	qdf_mem_zero(&roam_info, sizeof(tCsrRoamInfo));
+	qdf_mem_zero(&roam_info, sizeof(struct csr_roam_info));
 	csr_roam_call_callback(mac_ctx, session_id, &roam_info, roamid,
 			       eCSR_ROAM_FT_START, eCSR_ROAM_RESULT_SUCCESS);
 
-	qdf_mem_zero(&roam_info, sizeof(tCsrRoamInfo));
+	qdf_mem_zero(&roam_info, sizeof(struct csr_roam_info));
 	csr_neighbor_roam_state_transition(mac_ctx,
 			eCSR_NEIGHBOR_ROAM_STATE_REASSOCIATING, session_id);
 
diff --git a/core/sme/src/csr/csr_inside_api.h b/core/sme/src/csr/csr_inside_api.h
index 59a20ca..c1c955a 100644
--- a/core/sme/src/csr/csr_inside_api.h
+++ b/core/sme/src/csr/csr_inside_api.h
@@ -344,7 +344,8 @@
 				*pResult);
 
 QDF_STATUS csr_roam_call_callback(tpAniSirGlobal pMac, uint32_t sessionId,
-				  tCsrRoamInfo *roam_info, uint32_t roamId,
+				  struct csr_roam_info *roam_info,
+				  uint32_t roamId,
 				  eRoamCmdStatus u1, eCsrRoamResult u2);
 QDF_STATUS csr_roam_issue_connect(tpAniSirGlobal pMac, uint32_t sessionId,
 				  tCsrRoamProfile *pProfile,
@@ -486,7 +487,7 @@
 bool csr_roam_complete_roaming(tpAniSirGlobal pMac, uint32_t sessionId,
 			       bool fForce, eCsrRoamResult roamResult);
 void csr_roam_completion(tpAniSirGlobal pMac, uint32_t sessionId,
-			 tCsrRoamInfo *roam_info, tSmeCmd *pCommand,
+			 struct csr_roam_info *roam_info, tSmeCmd *pCommand,
 			 eCsrRoamResult roamResult, bool fSuccess);
 void csr_roam_cancel_roaming(tpAniSirGlobal pMac, uint32_t sessionId);
 void csr_apply_channel_power_info_wrapper(tpAniSirGlobal pMac);
@@ -972,7 +973,7 @@
 
 void csr_call_roaming_completion_callback(tpAniSirGlobal pMac,
 					  struct csr_roam_session *pSession,
-					  tCsrRoamInfo *roam_info,
+					  struct csr_roam_info *roam_info,
 					  uint32_t roamId,
 					  eCsrRoamResult roamResult);
 /**
diff --git a/core/sme/src/csr/csr_neighbor_roam.c b/core/sme/src/csr/csr_neighbor_roam.c
index cbf493f..fe29487 100644
--- a/core/sme/src/csr/csr_neighbor_roam.c
+++ b/core/sme/src/csr/csr_neighbor_roam.c
@@ -109,9 +109,9 @@
 				tSirMacAddr bssid,
 				eRoamCmdStatus status)
 {
-	tCsrRoamInfo *roam_info;
+	struct csr_roam_info *roam_info;
 
-	roam_info = qdf_mem_malloc(sizeof(tCsrRoamInfo));
+	roam_info = qdf_mem_malloc(sizeof(struct csr_roam_info));
 	if (NULL == roam_info) {
 		sme_err("Memory allocation failed!");
 	} else {
@@ -1090,7 +1090,7 @@
 		&pMac->roam.neighborRoamInfo[session_id];
 	struct csr_roam_session *session = &pMac->roam.roamSession[session_id];
 #ifdef WLAN_FEATURE_ROAM_OFFLOAD
-	tCsrRoamInfo roamInfo;
+	struct csr_roam_info roamInfo;
 	tpSirSetActiveModeSetBncFilterReq msg;
 #endif
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
diff --git a/core/sme/src/csr/csr_roam_preauth.c b/core/sme/src/csr/csr_roam_preauth.c
index 9b90211..af78925 100644
--- a/core/sme/src/csr/csr_roam_preauth.c
+++ b/core/sme/src/csr/csr_roam_preauth.c
@@ -629,7 +629,7 @@
 {
 	tpAniSirGlobal mac_ctx = PMAC_STRUCT(hal);
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	eCsrAuthType conn_Auth_type;
 	uint32_t session_id = preauth_rsp->smeSessionId;
 	struct csr_roam_session *csr_session = CSR_GET_SESSION(mac_ctx,
diff --git a/core/sme/src/nan/nan_datapath_api.c b/core/sme/src/nan/nan_datapath_api.c
index 8798acc..f8675a8 100644
--- a/core/sme/src/nan/nan_datapath_api.c
+++ b/core/sme/src/nan/nan_datapath_api.c
@@ -402,7 +402,7 @@
 					uint32_t result,
 					uint32_t *roam_status,
 					uint32_t *roam_result,
-					tCsrRoamInfo *roam_info)
+					struct csr_roam_info *roam_info)
 {
 
 	switch (result) {
@@ -602,7 +602,7 @@
  */
 void sme_ndp_msg_processor(tpAniSirGlobal mac_ctx, struct scheduler_msg *msg)
 {
-	tCsrRoamInfo roam_info = {0};
+	struct csr_roam_info roam_info = {0};
 	eCsrRoamResult result;
 	uint32_t session_id;
 	tListElem *entry = NULL;
diff --git a/core/sme/src/p2p/p2p_api.c b/core/sme/src/p2p/p2p_api.c
index be9afde..c47ff24 100644
--- a/core/sme/src/p2p/p2p_api.c
+++ b/core/sme/src/p2p/p2p_api.c
@@ -133,7 +133,7 @@
 	QDF_STATUS status = QDF_STATUS_SUCCESS;
 	tListElem *pEntry = NULL;
 	tSmeCmd *pCommand = NULL;
-	tCsrRoamInfo RoamInfo;
+	struct csr_roam_info RoamInfo;
 	struct sir_roc_rsp *rsp =  (struct sir_roc_rsp *)pMsg;
 
 	csr_get_active_scan_entry(pMac, rsp->scan_id, &pEntry);
diff --git a/core/sme/src/rrm/sme_rrm.c b/core/sme/src/rrm/sme_rrm.c
index d73118e..500a36f 100644
--- a/core/sme/src/rrm/sme_rrm.c
+++ b/core/sme/src/rrm/sme_rrm.c
@@ -283,7 +283,7 @@
 	uint8_t bss_counter = 0;
 	tCsrScanResultInfo *cur_result = NULL;
 	tpRrmSMEContext rrm_ctx = &mac_ctx->rrm.rrmSmeContext;
-	tCsrRoamInfo roam_info;
+	struct csr_roam_info roam_info;
 	tSirEseBcnReportRsp bcn_rpt_rsp;
 	tpSirEseBcnReportRsp bcn_report = &bcn_rpt_rsp;
 	tpCsrEseBeaconReqParams cur_meas_req = NULL;
@@ -423,7 +423,7 @@
 	uint8_t counter = 0;
 	tpRrmSMEContext rrm_ctx = &mac_ctx->rrm.rrmSmeContext;
 	uint32_t session_id;
-	tCsrRoamInfo *roam_info;
+	struct csr_roam_info *roam_info;
 
 	qdf_mem_zero(&filter, sizeof(filter));
 	qdf_mem_zero(scanresults_arr,
diff --git a/core/sap/src/sap_api_link_cntl.c b/core/sap/src/sap_api_link_cntl.c
index 9c73117..9bf2b40 100644
--- a/core/sap/src/sap_api_link_cntl.c
+++ b/core/sap/src/sap_api_link_cntl.c
@@ -418,7 +418,7 @@
 static void
 wlansap_roam_process_ch_change_success(tpAniSirGlobal mac_ctx,
 				      struct sap_context *sap_ctx,
-				      tCsrRoamInfo *csr_roam_info,
+				      struct csr_roam_info *csr_roam_info,
 				      QDF_STATUS *ret_status)
 {
 	tWLAN_SAPEvent sap_event;
@@ -790,7 +790,7 @@
 static void
 wlansap_roam_process_infra_assoc_ind(struct sap_context *sap_ctx,
 				     eCsrRoamResult roam_result,
-				     tCsrRoamInfo *csr_roam_info,
+				     struct csr_roam_info *csr_roam_info,
 				     QDF_STATUS *ret_status)
 {
 	QDF_STATUS qdf_status;
@@ -880,7 +880,7 @@
 /**
  * wlansap_roam_callback() - Callback for Roam (connection status) Events
  * @ctx             : pContext passed in with the roam request
  * @csr_roam_info   : Pointer to a tCsrRoamInfo
  * @roamId          : to identify the callback related roam request.
  *                    0 means unsolicit
  * @roam_status     : Flag indicating the status of the callback
@@ -892,7 +892,8 @@
  * Return: Status of operation
  */
 QDF_STATUS
-wlansap_roam_callback(void *ctx, tCsrRoamInfo *csr_roam_info, uint32_t roamId,
+wlansap_roam_callback(void *ctx, struct csr_roam_info *csr_roam_info,
+		      uint32_t roamId,
 		      eRoamCmdStatus roam_status, eCsrRoamResult roam_result)
 {
 	/* sap_ctx value */
@@ -880,7 +880,7 @@
  * wlansap_roam_callback() - Callback for Roam (connection status) Events
  * @ctx             : pContext passed in with the roam request
- * @csr_roam_info   : Pointer to a tCsrRoamInfo
+ * @csr_roam_info   : Pointer to a struct csr_roam_info
  * @roamId          : to identify the callback related roam request.
  *                    0 means unsolicit